<?php
/**
 * Plugin Name: Ray's Login Widget
 * Plugin URI: http://www.raymercer.net
 * Description: A simple widget to replace the default Wordpress "meta" widget
 * Version: 0.1
 * Author: Ray Mercer
 * Author URI: http://www.raymercer.net
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */

/**
 * Add function to widgets_init that'll load our widget.
 * @since 0.1
 */
add_action( 'widgets_init', 'rays_load_widgets' );

/**
 * Register our widget.
 * 'Rays_Login_Widget' is the widget class used below.
 *
 * @since 0.1
 */
function rays_load_widgets() {
	register_widget( 'Rays_Login_Widget' );
}

/**
 * Example Widget class.
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update.  Nice!
 *
 * @since 0.1
 */
class Rays_Login_Widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function Rays_Login_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'rays_login', 'description' => __('A simple widget to replace the default Wordpress meta widget', 'rays_login') );

		/* Create the widget. */
		$this->WP_Widget( 'rays-login-widget', __('Rays Login Widget', 'rays_login'), $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] ) ;

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;
?>
			<ul>
			<?php wp_register(); ?>
			<li><?php wp_loginout(); ?></li>
			<?php wp_meta(); ?>
			</ul>
<?php



		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );

		return $instance;
	}

	/**
	 * Displays the widget settings controls on the widget panel.
	 * Make use of the get_field_id() and get_field_name() function
	 * when creating your form elements. This handles the confusing stuff.
	 */
	function form( $instance ) {

		$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
		$title = strip_tags($instance['title']);
?>
		<!-- Widget Title: Ray's Login Widget -->

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'hybrid'); ?></label>
			<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" style="width:100%;" />
		</p>

	<?php
	}
}

?>